Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Directory ¶
type Directory interface {
common.Node
// List candidate invoker list for the current Directory.
// NOTICE: The invoker list returned to the caller may be backed by the same data hold by the current Directory
// implementation for the sake of performance consideration. This requires the caller of List() shouldn't modify
// the return result directly.
List(invocation base.Invocation) []base.Invoker
// Subscribe listen to registry instances
Subscribe(url *common.URL) error
}
Directory implementations include RegistryDirectory, ServiceDiscoveryRegistryDirectory, StaticDirectory
Click to show internal directories.
Click to hide internal directories.