metadata

package
v3.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 27, 2025 License: Apache-2.0 Imports: 8 Imported by: 2

Documentation

Index

Constants

const (
	DefaultGroup = "mapping"
)

Variables

This section is empty.

Functions

func GetNameMappingInstance

func GetNameMappingInstance() mapping.ServiceNameMapping

GetNameMappingInstance return an instance, if not found, it creates one

Types

type ServiceNameMapping added in v3.3.0

type ServiceNameMapping struct {
}

ServiceNameMapping is the implementation based on metadata report it's a singleton

func (*ServiceNameMapping) Get added in v3.3.0

Get will return the application-level services. If not found, the empty set will be returned.

func (*ServiceNameMapping) Map added in v3.3.0

func (d *ServiceNameMapping) Map(url *common.URL) error

Map will map the service to this application-level service

func (*ServiceNameMapping) Remove added in v3.3.0

func (d *ServiceNameMapping) Remove(url *common.URL) error

Jump to