Documentation
¶
Index ¶
Constants ¶
const (
DefaultGroup = "mapping"
)
Variables ¶
This section is empty.
Functions ¶
func GetNameMappingInstance ¶
func GetNameMappingInstance() mapping.ServiceNameMapping
GetNameMappingInstance return an instance, if not found, it creates one
Types ¶
type ServiceNameMapping ¶ added in v3.3.0
type ServiceNameMapping struct {
}
ServiceNameMapping is the implementation based on metadata report it's a singleton
func (*ServiceNameMapping) Get ¶ added in v3.3.0
func (d *ServiceNameMapping) Get(url *common.URL, listener mapping.MappingListener) (*gxset.HashSet, error)
Get will return the application-level services. If not found, the empty set will be returned.
Click to show internal directories.
Click to hide internal directories.