Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MetadataReport ¶
type MetadataReport interface {
// GetAppMetadata get metadata info from report
GetAppMetadata(application, revision string) (*info.MetadataInfo, error)
// PublishAppMetadata publish metadata info to report
PublishAppMetadata(application, revision string, info *info.MetadataInfo) error
// RegisterServiceAppMapping map the specified Dubbo service interface to current Dubbo app name
RegisterServiceAppMapping(interfaceName, group string, application string) error
// GetServiceAppMapping get the app names from the specified Dubbo service interface
GetServiceAppMapping(interfaceName, group string, l mapping.MappingListener) (*gxset.HashSet, error)
// RemoveServiceAppMappingListener remove the serviceMapping listener by key and group
RemoveServiceAppMappingListener(interfaceName, group string) error
}
MetadataReport is an interface of remote metadata report.
type MetadataReportFactory ¶ added in v3.3.0
type MetadataReportFactory interface {
CreateMetadataReport(*common.URL) MetadataReport
}
MetadataReportFactory interface will create metadata report
Click to show internal directories.
Click to hide internal directories.