Documentation
¶
Index ¶
- type ClientOption
- type ClientOptions
- type Exporter
- type Invocation
- type Invoker
- type Option
- type Protocol
- type RPCResult
- type RPCStatue
- type Result
- type ServerOption
- func WithID(id string) ServerOption
- func WithIp(ip string) ServerOption
- func WithMaxServerRecvMsgSize(size string) ServerOptiondeprecated
- func WithMaxServerSendMsgSize(size string) ServerOption
- func WithParams(params any) ServerOption
- func WithPort(port int) ServerOption
- func WithServerOptions(options ...ServerOption) ServerOption
- type ServerOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClientOption ¶ added in v3.3.1
type ClientOption interface {
// contains filtered or unexported methods
}
func WithClientOptions ¶ added in v3.3.1
func WithClientOptions(options ...ClientOption) ClientOption
WithClientOptions composes multiple ClientOptions into one.
type ClientOptions ¶ added in v3.3.1
type ClientOptions struct {
ProtocolClient *global.ClientProtocolConfig
ID string
}
func NewClientOptions ¶ added in v3.3.1
func NewClientOptions(opts ...ClientOption) *ClientOptions
type Exporter ¶
Exporter Deprecated: base.Exporter type alias, just for compatible with old generate pb.go file
type Invocation ¶
type Invocation = base.Invocation
Invocation Deprecated: base.Invocation type alias, just for compatible with old generate pb.go file
type Invoker ¶
Invoker Deprecated: base.Invoker type alias, just for compatible with old generate pb.go file
type Option ¶ added in v3.3.0
type Option interface {
ClientOption
ServerOption
}
func WithDubbo ¶ added in v3.3.0
func WithDubbo() Option
TODO: Maybe we need configure dubbo protocol future.
func WithJSONRPC ¶ added in v3.3.0
func WithJSONRPC() Option
TODO: Maybe we need configure jsonRPC protocol future.
func WithOptions ¶ added in v3.3.1
WithOptions composes multiple Options into one.
func WithProtocol ¶ added in v3.3.0
NOTE: This option can't be configured freely.
func WithREST ¶ added in v3.3.0
func WithREST() Option
TODO: Maybe we need configure REST protocol future.
func WithTriple ¶ added in v3.3.0
type Protocol ¶
Protocol Deprecated: base.Protocol type alias, just for compatible with old generate pb.go file
type RPCResult ¶
RPCResult Deprecated: base.RPCResult type alias, just for compatible with old generate pb.go file
type RPCStatue ¶ added in v3.3.1
RPCStatue Deprecated: base.RPCStatue type alias, just for compatible with old generate pb.go file
type Result ¶
Result Deprecated: base.Result type alias, just for compatible with old generate pb.go file
type ServerOption ¶ added in v3.3.1
type ServerOption interface {
// contains filtered or unexported methods
}
func WithID ¶ added in v3.3.0
func WithID(id string) ServerOption
WithID specifies the id of protocol.Options. Then you could configure server.WithProtocolIDs and server.WithServer_ProtocolIDs to specify which protocol you need to use in multi-protocols scenario.
func WithIp ¶ added in v3.3.0
func WithIp(ip string) ServerOption
func WithMaxServerRecvMsgSize
deprecated
added in
v3.3.0
func WithMaxServerRecvMsgSize(size string) ServerOption
Deprecated: use triple.WithMaxServerRecvMsgSize instead.
func WithMaxServerSendMsgSize ¶ added in v3.3.0
func WithMaxServerSendMsgSize(size string) ServerOption
Deprecated:use triple.WithMaxServerSendMsgSize instead.
func WithParams ¶ added in v3.3.0
func WithParams(params any) ServerOption
func WithPort ¶ added in v3.3.0
func WithPort(port int) ServerOption
func WithServerOptions ¶ added in v3.3.1
func WithServerOptions(options ...ServerOption) ServerOption
WithServerOptions composes multiple ServerOptions into one.
type ServerOptions ¶ added in v3.3.1
type ServerOptions struct {
Protocol *global.ProtocolConfig
ID string
}
func NewServerOptions ¶ added in v3.3.1
func NewServerOptions(opts ...ServerOption) *ServerOptions
Directories
¶
| Path | Synopsis |
|---|---|
|
Package dubbo implements dubbo rpc protocol.
|
Package dubbo implements dubbo rpc protocol. |
|
example/new/client
command
|
|
|
example/new/server
command
|
|
|
Package dubbo3 implements dubbo3.0 rpc protocol.
|
Package dubbo3 implements dubbo3.0 rpc protocol. |
|
Package grpc implements grpc rpc protocol.
|
Package grpc implements grpc rpc protocol. |
|
Package jsonrpc implements json rpc protocol.
|
Package jsonrpc implements json rpc protocol. |
|
Package mock is a generated GoMock package.
|
Package mock is a generated GoMock package. |
|
Package rest implements restful rpc protocol.
|
Package rest implements restful rpc protocol. |
|
health/triple_health
Code generated by protoc-gen-triple.
|
Code generated by protoc-gen-triple. |
|
reflection/triple_reflection
Code generated by protoc-gen-triple.
|
Code generated by protoc-gen-triple. |
|
triple_protocol
Package triple is a slim RPC framework built on Protocol Buffers and net/http.
|
Package triple is a slim RPC framework built on Protocol Buffers and net/http. |
|
triple_protocol/internal/assert
Package assert is a minimal assert package using reflection.
|
Package assert is a minimal assert package using reflection. |
|
triple_protocol/internal/gen/proto/connect/ping/v1/pingv1connect
The connect.ping.v1 package contains an echo service designed to test the connect-go implementation.
|
The connect.ping.v1 package contains an echo service designed to test the connect-go implementation. |