Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MetadtaServiceVersionCustomizer ¶
type MetadtaServiceVersionCustomizer struct {
}
MetadtaServiceVersionCustomizer will try to add meta-v key to instance metadata
func (*MetadtaServiceVersionCustomizer) Customize ¶
func (p *MetadtaServiceVersionCustomizer) Customize(instance registry.ServiceInstance)
Customize put the the string like [{"protocol": "dubbo", "port": 123}] into instance's metadata
func (*MetadtaServiceVersionCustomizer) GetPriority ¶
func (p *MetadtaServiceVersionCustomizer) GetPriority() int
GetPriority will return 0, which means it will be invoked at the beginning
type ProtocolPortsMetadataCustomizer ¶
type ProtocolPortsMetadataCustomizer struct {
}
ProtocolPortsMetadataCustomizer will update the endpoints
func (*ProtocolPortsMetadataCustomizer) Customize ¶
func (p *ProtocolPortsMetadataCustomizer) Customize(instance registry.ServiceInstance)
Customize put the the string like [{"protocol": "dubbo", "port": 123}] into instance's metadata
func (*ProtocolPortsMetadataCustomizer) GetPriority ¶
func (p *ProtocolPortsMetadataCustomizer) GetPriority() int
GetPriority will return 0, which means it will be invoked at the beginning
Click to show internal directories.
Click to hide internal directories.